@@ -343,10 +343,13 @@ static int stszin(int size)
     u32in();
     // Number of entries
     mp4config.frame.ents = u32in();
-    // fixme error checking
     // fixme: check atom size
     mp4config.frame.data = malloc(sizeof(*mp4config.frame.data)
                                   * (mp4config.frame.ents + 1));
+
+    if (!mp4config.frame.data)
+        return ERR_FAIL;
+
     ofs = 0;
     mp4config.frame.data[0] = ofs;
     for (cnt = 0; cnt < mp4config.frame.ents; cnt++)
@@ -358,6 +361,9 @@ static int stszin(int size)
             mp4config.frame.maxsize = fsize;
 
         mp4config.frame.data[cnt + 1] = ofs;
+
+        if (ofs < mp4config.frame.data[cnt])
+            return ERR_FAIL;
     }
 
     return size;
@@ -951,7 +957,7 @@ int mp4read_seek(int framenum)
 
 static void mp4info(void)
 {
-    fprintf(stderr, "Modification Time:\t\t%s", mp4time(mp4config.mtime));
+    fprintf(stderr, "Modification Time:\t\t%s\n", mp4time(mp4config.mtime));
     fprintf(stderr, "Samplerate:\t\t%d\n", mp4config.samplerate);
     fprintf(stderr, "Total samples:\t\t%d\n", mp4config.samples);
     fprintf(stderr, "Total channels:\t\t%d\n", mp4config.channels);
@@ -1002,9 +1008,11 @@ int mp4read_open(char *name)
     }
 
     // alloc frame buffer
-    // fixme: error checking
     mp4config.bitbuf.data = malloc(mp4config.frame.maxsize);
 
+    if (!mp4config.bitbuf.data)
+        goto err;
+
     if (mp4config.verbose.header)
     {
         mp4info();
